@@ -38,6 +38,8 @@
 #include "program.h"
 #include "banner.h"
 #include "code-dialog.h"
+#include "color-chooser-dialog.h"
+#include "color-chooser.h"
 
 extern "C"
 {
@@ -49,6 +51,8 @@ GType hildon_calendar_popup_get_type(void);
 GType hildon_caption_get_type(void);
 GType hildon_code_dialog_get_type(void);
 GType hildon_color_button_get_type(void);
+GType hildon_color_chooser_get_type(void);
+GType hildon_color_chooser_dialog_get_type(void);
 GType hildon_controlbar_get_type(void);
 GType hildon_date_editor_get_type(void);
 GType hildon_find_toolbar_get_type(void);
@@ -83,6 +87,8 @@ namespace Hildon {  class CalendarPopup_Class { public: static Glib::ObjectBase*
 namespace Hildon {  class Caption_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Hildon {  class CodeDialog_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Hildon {  class ColorButton_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Hildon {  class ColorChooser_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
+namespace Hildon {  class ColorChooserDialog_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Hildon {  class Controlbar_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Hildon {  class DateEditor_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
 namespace Hildon {  class FindToolbar_Class { public: static Glib::ObjectBase* wrap_new(GObject*); };  }
@@ -117,6 +123,8 @@ void wrap_init()
   Glib::wrap_register(hildon_caption_get_type(), &Hildon::Caption_Class::wrap_new);
   Glib::wrap_register(hildon_code_dialog_get_type(), &Hildon::CodeDialog_Class::wrap_new);
   Glib::wrap_register(hildon_color_button_get_type(), &Hildon::ColorButton_Class::wrap_new);
+  Glib::wrap_register(hildon_color_chooser_get_type(), &Hildon::ColorChooser_Class::wrap_new);
+  Glib::wrap_register(hildon_color_chooser_dialog_get_type(), &Hildon::ColorChooserDialog_Class::wrap_new);
   Glib::wrap_register(hildon_controlbar_get_type(), &Hildon::Controlbar_Class::wrap_new);
   Glib::wrap_register(hildon_date_editor_get_type(), &Hildon::DateEditor_Class::wrap_new);
   Glib::wrap_register(hildon_find_toolbar_get_type(), &Hildon::FindToolbar_Class::wrap_new);
@@ -145,6 +153,8 @@ void wrap_init()
   Hildon::Caption::get_type();
   Hildon::CodeDialog::get_type();
   Hildon::ColorButton::get_type();
+  Hildon::ColorChooser::get_type();
+  Hildon::ColorChooserDialog::get_type();
   Hildon::Controlbar::get_type();
   Hildon::DateEditor::get_type();
   Hildon::FindToolbar::get_type();
